.customersatisfaction-menu-wrapper {
    display: flex;
    justify-content: space-between;
    margin-bottom: 3em;
    padding: 1em;
    background-color: #e6e6e6;

    .plone-btn {
        margin-right: 1em;
        &:last-child {
            margin-right: 0;
        }
        font-size: 14px;
        font-weight: bold;
        border-radius: 4px;
    }
}
#content-core a.plone-btn:hover {
    border-bottom: 1px solid #cccccc;
    box-shadow: none;
}
