.customersatisfaction-menu-wrapper{display:flex;justify-content:space-between;margin-bottom:3em;padding:1em;background-color:#e6e6e6}.customersatisfaction-menu-wrapper .plone-btn{margin-right:1em;font-size:14px;font-weight:700;border-radius:4px}.customersatisfaction-menu-wrapper .plone-btn:last-child{margin-right:0}#content-core a.plone-btn:hover{border-bottom:1px solid #ccc;box-shadow:none}
.customer-satisfaction-history-list [role=heading]{background-color:transparent}.customer-satisfaction-history-list .channels{width:100%;overflow:scroll;max-height:4rem}.customer-satisfaction-history-list .action.editItem:active,.customer-satisfaction-history-list .action.editItem:hover{box-shadow:none}.customer-satisfaction-history-list .search-wrapper{display:flex}.customer-satisfaction-history-list .search-wrapper input{border-bottom-right-radius:0;border-top-right-radius:0;height:unset}.customer-satisfaction-history-list .search-wrapper button{border-left:none;border-bottom-left-radius:0;border-top-left-radius:0}.customer-satisfaction-history-list .status .success{color:#5cb85c}.customer-satisfaction-history-list .status .error{color:#d9534f}.customer-satisfaction-history-list .type-select{width:23em;margin-right:1rem}.customer-satisfaction-history-list .rdt_TableCol{background-color:#e8e8e8}.customer-satisfaction-history-list .rdt_TableCell a:focus,.customer-satisfaction-history-list .rdt_TableCell a:hover{border-bottom:1px solid!important}


/*# sourceMappingURL=history.css.map*/